---
Title: Python interface
Authors: Tamas, Jutta
Topics:
  - installation
  - interface through software
status: review
---

### Python environment

KM3NeT develops open source Python software for accessing and working with data taken by the detector, produced in simulations or in other analysis pipelines e.g. event reconstructions, and a number of other types like metadata, provenance history and environmental data. The software is following the Semantic Versioning 2.0 (https://semver.org) conventions and releases are automatically triggered on the GitLab CI by annotated Git tags. These releases including alpha and beta releases are uploaded to the publicly accessible Python Package Index, which is the main repository of software for the Python programming language. The installation of these packages is as simple as executing `pip install PACKAGE_NAME`. Additionally, the packages can also be installed directly from the GitLab repositories for example in case of experimental branches.

#### Preferred python packages
The general philosophy behind all Python packages is to build a bridge to commonly use open source scientific tools, libraries and frameworks. While the common base is built on [NumPy](https://numpy.org), the de facto standard for scientific, numerical computing in Python, other popular packages from the [SciPy stack](https://www.scipy.org) are highly preferred. Examples are [Matplotlib](https://matplotlib.org) to create publication quality plots, [Pandas](https://pandas.pydata.org) which is used to work with tabular data, [Astropy](https://www.astropy.org) for astronomical calculations or [numba](http://numba.pydata.org) for high-performance low level optimisations.

#### Preferred formats for interoperability
The output format is preferably CSV and JSON to maximise interoperability. For larger or more complex datasets, two additional formats are supported. [HDF5](https://www.hdfgroup.org) which is a widely used data format in science and accessible in many popular computer languages is used to store data from every tier, including uncalibrated low-level data and high-level reconstruction summaries. Additionally and mainly for astronomical data, the [FITS](https://fits.gsfc.nasa.gov) dataformat is considered if required due to its high popularity among astronomers.

#### Python interface to KM3NeT data

In addition to offering services and data through the KM3NeT Open Data Center, the [openkm3](https://git.km3net.de/open-data/openkm3) python client was developed to directly use open data in python from local computer and within e.g. Jupyter notebooks. It interlinks with the ODC REST-API and allows to query metadata of the resources and collections. In additionn to that, it offers function to interpret the data according to its KM3NeT type description ([ktype](Datamodels.md#ktype)), e.g. returning tables in a required format. These interface options will be expanded according to the requirements of data integrated to the ODC.
