---
Title: Registries
Author: Jutta
status: review
---

## Registries and Archiving

Registering the KM3NeT open science products with well-used platforms and assigning global identifiers is a key to findability of the data. As several KM3NeT servers (VO server, Open Data Center, Gitlab server) currently hold key data and software, products from these servers must be linked to larger platforms, ideally through semi-automatic integation. 
Also, at the end of the experiments, these products must be transferable from KM3NeT-hosted platforms to external repositories that ensure a longer lifetime of the digital products.

### Virtual Observatory Registry of Registries

#### Registry structure
In the VO, the KM3NeT server is registered as a registry of resources, i.e. of the datasets and services offered by the server. The [IVOA Registry of Registries (RofR)](https://ivoa.net/documents/Notes/RegistryOfRegistries/index.html) is a service maintained by IVOA that provides a mechanism for IVOA-compliant registries to learn about each other, being itself a compliant publishing registry which contains copies of the resource descriptions for all IVOA Registries.
When a resource metadata harvester harvests from these publishing registries, they can discover all published VO resources around the world.  

#### Identifiers
The KM3NeT VO server is registered with the following metadata to the RofR:

* name: KM3NeT Open Data Registry
* IVOA Identifier: `ivo://km3net.org/__system__/services/registry`
* OAI service endpoint: [http://vo.km3net.de/oai.xml](http://vo.km3net.de/oai.xml)

With this registration, KM3NeT data in the VO is fully findable within the Virtual Observatory, and each resource is identifiable through the naming of the individual endpoint of the service within the registry.

#### Archiving
At the end of the operation of KM3NeT and, in case the server can no longer be operated, various national organizations in the KM3NeT member states offer long-term supported repositories, to which the data sets could be transfered. As example, the [GaVO Data Center](http://dc.zah.uni-heidelberg.de/) provided by *Zentrum für Astronomie Heidelberg* on behalf of the German Astrophysical Virtual Observatory already hosts other ANTARES data sets and is provider of the DaCHS software used in the KM3NeT VO server, so transfer for archiving would, at least from the current day's perspective, be easy to achieve.

### DataCite and Zenodo
Universal citation of data and digital objects is generally handled through assignment of a [Digital Object Identifier (DOI)](https://www.doi.org/), a persistent identifier or handle used to identify objects uniquely which standardized by the International Organization for Standardization (ISO). The VO does support the integration of a DOI in their resource metadata, but does not provide an authority to assign DOIs, as the organization assigning a DOI generally also has to host the data to ensure the longevity of the data resource.

This leads to the dilemma that either the KM3NeT collaboration would have to become a member organization to e.g. [DataCite](https://datacite.org/), a global non-profit organisation that allows the assignment of DOIs to its member organizations, and operate a repository, or copy or mirror data to another repository in order to get a DOI. While this issue is not yet resolved and will be investigated further also in the context of the [ESCAPE project](https://projectescape.eu/), currently the second option is chosen for the small amount of data that is currently provided in this demonstrator. As hosting repository, [Zenodo](https://zenodo.org/) was chosen as well-established data repository in the physics community.

#### Registry structure
Zenodo was initiated by the [OpenAIRE project](https://www.openaire.eu/) and is hosted by CERN to offer a respository for research funded by the European Commission. It hosts publications, audio and visual media, software and datasets. It allows to create "communities" to group various resources, which has been used to create a [KM3NeT community](https://zenodo.org/communities/?p=KM3NeT). Upload can be managed through an API as well as through a web interface and standardized metadata is required.

#### Identifiers
Zenodo assigns DOIs to resources on upload if a DOI cannot be provided, making the dataset also easily citable. For this demonstrator, the event sample from the KM3NeT ORCA use case ("one week of ORCA") will be registered with Zenodo.

#### Archiving
As Zenodo offers long-term support of its resources and the data is already mirrored to the repository, archiving of the data can easily be accomplished.

### Software integration

#### Github, Zenodo and pypi
With [Github](https://github.com), a major platform exists for software development that also allows easy interaction between software developers on various projects. Open KM3NeT software is mirrored to Github, making the software findable for software developers. For grouping of the software, a [KM3NeT collection](https://github.com/KM3NeT) has also been established here.

For python-based software, easy installation via the pip package installer is integrated to the software packages. This installer links to the [Python Package Index (PyPI)](https://pypi.org/), a repository of software for the Python programming language. Here, a [KM3NeT user account](https://pypi.org/user/km3net/) has been established to group and administrate the software.

#### Identifiers
Neither Github nor PyPI make software citable in the strict sense, as they do not assign DOIs. However, Zenodo allows the integration of Github repositores to their platform. Therefore, the combination of mirroring software to Github, making it installable via PyPI and registering it with Zenodo makes the software accessible for community development, easily installable for users and citable in a scientific context.

#### Archiving
Both PyPI and Zenodo copy the relevant software to their platforms, copies of the source code are stored at multiple sites and make archiving easy.

* Software can be integrated directly from GitHub


-> will search for common approach in ESCAPE project.
