---
Title: ANTARES use case
Author: Rebecca
Topics:
  - short description analysis
  - data description
  - linking to notebooks & background
status: reviewed (Jannik)
---

# Example programs and Use cases

## ANTARES 2007-2017 Point source analysis

### Use case description
One of the primary goals of ANTARES is the identification of astrophysical neutrino sources, whose signature would appear as clusters of events at given coordinates in the sky. The ANTARES data used for this search are therefore a set of reconstructed neutrino arrival directions (in equatorial coordinates: right ascension RA, declination dec). 
The significance of a neutrino excess from a given sky position must be assessed over the expected background fluctuations using, for instance the Feldman-Cousins statistics.
The background is represented by atmospheric neutrinos: neutrinos originating from cosmic ray interactions in the Earth's atmosphere. Their arrival directions are isotropically distributed over the Earth's atmosphere, and result, at the ANTARES detector, uniform in right ascension and with a distribution in declination that depends on the detector geographical position (latitude). 

This ANTARES use case allows to inspect a sample of neutrino arrival directions in equatorial coordinates (RA, dec), evaluate from it the expected background rate for a user-selected sky position, and finally assess the significance of a cluster defined as all arrival directions that fall inside a given radius, selected by the user and indicated here 'region of interest' (RoI).

The background is evaluated in a declination band whose width is equal to the RoI diameter. The observed 'signal-like' events are those falling inside the RoI. Feldman and Cousins statistics [REF] is applied to determine the significance of this observation accounting for the fluctuations expected in the background. The aim of the analysis is set an upper limit, at a given confidence level, on the presence of a source at a given sky position. 

An upper limit on the number of events observed is not a very useful quantity for the community outside ANTARES, because it still contains the detector response. The upper limit on the number of events is therefore turned into an upper limit on the flux emitted by the source, which is the relevant information for drawing conclusions. To unfold the effect of the detector response, the acceptance of the detector is computed and provided alongside the ANTARES arrival direction data.

Here follows the step-by-step description of the code provided as [Jupyter notebook](https://open-data.pages.km3net.de/openscienceportal/notebooks/ANTARES_PointSource)

### Data set

ANTARES data has already been published to the VO for two data sets by using the services of the German Astrophysical Virtual Observatory (GAVO) which run the DaCHS software. The most recent public data sample of the 2007-2017 point source search is available through the ANTARES website, however, it is not findable through the VO and does therefore not match the FAIR criteria. Including ANTARES data in the development of future VO data types allowes to increase the chance for a long-term availability of high-quality ANTARES data. On the other hand, the KM3NeT VO server could be registered to the VO and protocols could be tested using the ANTARES 2007-2017 sample. 

The provided data set includes

* The **full event list** of 2007-2017 selected astrophysics neutrino candidates, provided through the VO server,
* Supplementary distributions from simulations provided via the ODC including:
  * the **detector acceptance** for a given source spectral index and declination,
  * the interpolated **distribution of background events** for a given declination and region of interest,
  * the **effective area** for an E^-2 source spectrum in three different zenith bands.
